#include <cstdio>
#include <iostream>
#include <vector>
#include <cmath>
#include <algorithm>

using namespace std;

const int MAX_N = 100333;



struct Query {
	int id, newAmount;
	Query(int id, int newAmount) : id(id), newAmount(newAmount) {}
	Query() {}
};

int n, m;
long long bank[MAX_N];
vector<Query> queries;


long long localNaive() {
	vector<long long> f(n + 1);
	f[1] = bank[1];
	for (int i = 2; i <= n; i++) {
		f[i] = max(f[i - 1], f[i - 2] + bank[i]);
	}
	return f[n];
}

void globalNaive() {
	cout << localNaive() << '\n';
	for (auto query : queries) {
		bank[query.id] = query.newAmount;
		cout << localNaive() << '\n';
	}
}


void read() {
	cin >> n >> m;
	for (int i = 1; i <= n; i++) {
		cin >> bank[i];
	}
	for (int i = 1; i <= m; i++) {
		int id, value;
		cin >> id >> value;
		queries.push_back({ id, value });
	}
}

struct Node {
	long long best[2][2];
	Node(long long value /*value >= 0*/) {
		best[0][0] = best[0][1] = best[1][0] = 0;
		best[1][1] = value;
	}
	Node() : best{ 0, 0, 0, 0 } {}

	long long answer() const {
		return max(max(best[0][0], best[0][1]), max(best[1][0], best[1][1]));
	}
};

Node tree[MAX_N * 4 + 47]; //for storing the segment
int sz;					   //for keeping smallest 2^k >= n

Node combine(const Node& left, const Node& right) {
	Node res;
	for (int leftFirst = 0; leftFirst < 2; leftFirst++) {
		for (int leftSecond = 0; leftSecond < 2; leftSecond++) {
			for (int rightFirst = 0; rightFirst < 2; rightFirst++) {
				for (int rightSecond = 0; rightSecond < 2; rightSecond++) {
					if (leftSecond + rightFirst < 2) {
						res.best[leftFirst][rightSecond] = max(res.best[leftFirst][rightSecond], left.best[leftFirst][leftSecond] + right.best[rightFirst][rightSecond]);
					}
				}
			}
		}
	}
	return res;
}

void update(int v, int value) {
	v = v + sz - 1;
	tree[v] = Node(value);
	v /= 2;
	while (v > 0) {
		tree[v] = combine(tree[v * 2], tree[v * 2 + 1]);
		v /= 2;
	}
}

void buildTree() {
	sz = 1;
	while (sz < n) {
		sz *= 2;
	}
	for (int i = 1; i <= n; i++) {
		tree[i + sz - 1] = Node(bank[i]);
	}
	for (int i = sz - 1; i > 0; i--) {
		tree[i] = combine(tree[i * 2], tree[i * 2 + 1]);
	}
}

void solve() {
	buildTree();
	cout << tree[1].answer() << '\n'; //peeking at the answer from the root
	for (auto& query : queries) {
		update(query.id, query.newAmount);
		cout << tree[1].answer() << '\n';
	}
}


int main() {
    //freopen("robbery.dat", "r", stdin);
	//freopen("robbery.sol", "w", stdout);
	ios_base::sync_with_stdio(false);
	read();
	//globalNaive();
	//cout << "______\n";
	solve();
}
